==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/lw6-config.h <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6_LW6_CONFIG_H
#define LIQUIDWAR6_LW6_CONFIG_H

/*
 * These values are set from ./configure script. They are
 * Liquid War 6 specific and are therefore not in config.h
 * which is handled by autoconf and contains "standard" values.
 * The fact that this file is changed each time one runs
 * ./configure with new options garantees that files are actually
 * compiled with the right options. Additionnally, it avoids
 * passing a bazillions -DLW6_VAR=value options to the compiler.
 * And in can be installed in $prefix/include so that one knows
 * how things have been compiled.
 */
#define LW6_HOSTNAME "watt"
#define LW6_CONFIGURE_ARGS "'--prefix=/home/ufoot/home/local/liquidwar6'"
#define LW6_TARGET_CPU "powerpc"

#endif

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/lw6-config.h <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#ifndef LIQUIDWAR6_LW6_CONFIG_H
#define LIQUIDWAR6_LW6_CONFIG_H

/*
 * These values are set from ./configure script. They are
 * Liquid War 6 specific and are therefore not in config.h
 * which is handled by autoconf and contains "standard" values.
 * The fact that this file is changed each time one runs
 * ./configure with new options garantees that files are actually
 * compiled with the right options. Additionnally, it avoids
 * passing a bazillions -DLW6_VAR=value options to the compiler.
 * And in can be installed in $prefix/include so that one knows
 * how things have been compiled.
 */
#define LW6_HOSTNAME "guenegaud"
#define LW6_CONFIGURE_ARGS "'--prefix=/home/ufoot/home/build/liquidwar6'"
#define LW6_TARGET_CPU "x86_64"

#endif
